# Copyright 2023 Pablo Castellano
# SPDX-License-Identifier: GPL-3.0-or-later
from pmb.qemu.run import run as run
